@@ -39,14 +39,13 @@ call.dots <- function(
     }
     if(is.null(CALLARGS))
         CALLARGS <- callargs(call.dots)
-
     args <- deprefix(FUNC=FUNC, PREFIX=PREFIX, ..., DROP=DROP, KEEP=KEEP,
                      TRACE=TRACE, FNAME=FNAME, FORMALS=FORMALS,
                      SCALAR=SCALAR, CALLARGS=CALLARGS)
 
     do.call.trace(FUNC, args, FNAME, trace=TRACE)
 }
-# A version of call.dots specialized for calling plot functions.
+# A version of call.dots specialized for calling plotting functions.
 # This drops all args in dots except those matching PREFIX and PLOT.ARGS.
 
 call.plot <- function(
@@ -183,8 +182,8 @@ PLOTMO.ARGS <- c( "caption.", "cex.", "col.", "contour.", "cum.",
     "degree1.", "degree2.", "density.", "filled.contour.", "font.", "func.",
     "grid.", "heatmap.", "image.", "jitter.", "legend.", "label.", "level.",
     "line.", "lines.", "lty.", "lty.", "lwd.", "main.", "mtext.",
-    "nresiduals", "par.", "pch.", "persp.", "plot.", "plotmath.", "qq.",
-    "qqline.", "pt.", "response.", "rug.", "smooth.", "text.", "title.",
+    "nresiduals", "par.", "pch.", "persp.", "plot.", "plotmath.", "prednames.",
+    "qq.", "qqline.", "pt.", "response.", "rug.", "smooth.", "text.", "title.",
     "vfont.")
 
 # from now on in this module function defs are in alphabetic order
@@ -338,7 +337,7 @@ expand.dotnames <- function(
         }
         match <- charmatch(raw.dotname, formals)
 
-        if(is.na(match)) {
+        if(anyNA(match)) {
             # No match, not necessarily a problem assuming FUNC has a dots formal arg.
             # We will allow FUNC to check for itself later (if someone calls it).
             NULL
@@ -435,7 +434,7 @@ higher.caller.to.deprefix <- function(..., FNAME=FNAME)
     higher.fname <- "FUNC"
     try.was.used <- FALSE
     for(i in max(ncalls-10, 1) : ncalls) {
-        fname <- paste(sys.calls[[i]])[1]
+        fname <- paste(sys.calls[[i]][1]) # TODO is [1] in the correct position?
         if(grepl("^call\\.|^deprefix", fname))
             break
         if(grepl("^doTry|^try", fname))
@@ -450,8 +449,8 @@ higher.caller.to.deprefix <- function(..., FNAME=FNAME)
     # use try here for paranoia
     args <- try(higher.call.args(..., CALLX=call, FNAME=FNAME), silent=TRUE)
     if(is.try.err(args))
-        args <- sprintf("%s, ...", FNAME)
-    sprintf("%s called %s(%s)", higher.fname, fname, args)
+        args <- sprint("%s, ...", FNAME)
+    sprint("%s called %s(%s)", higher.fname, fname, args)
 }
 init.fname <- function(FNAME, FUNC, TRACE)
 {
@@ -554,7 +553,7 @@ stopif.unnamed.dot <- function(dots, higher.caller, ...) # called from deprefix(
 {
     which <- which(names(dots) == "")
     if(length(which)) {
-        call <- sprintf("\n       %s\n",
+        call <- sprint("\n       %s\n",
             paste0(strwrap(higher.caller, width=getOption("width"), exdent=10),
                    collapse="\n"))
         dot <- dots[[ which[1] ]]
