@@ -23,7 +23,7 @@ plot_gbm <- function(object=stop("no 'object' argument"),
     check.classname(object, "object", c("gbm", "GBMFit"))
     obj <- object
     if((!is.numeric(smooth) && !is.logical(smooth)) ||
-       any(smooth != 0 && smooth != 1))
+       any(smooth != 0 & smooth != 1))
         stop0("smooth should be a four-element vector specifying if train, ",
               "test, CV, and OOB curves are smoothed, e.g. smooth=c(0,0,0,1)")
     smooth <- rep_len(smooth, 4) # recycle smooth if necessary
@@ -314,8 +314,7 @@ gbm.top.labels <- function(leg.imin, leg.text, leg.col)
     leg.col[leg.col == "darkgray"] <- lighten("darkgray", -0.1)
     usr <- par("usr") # xmin, xmax, ymin, ymax
     # TODO spread.labs is buggy for horizontal labels (too much space sometimes)?
-    x <- TeachingDemos::spread.labs(leg.imin,
-            mindiff=par("cex") * max(strwidth(paste0(leg.imin, " "))),
+    x <- spread.labs(leg.imin,mindiff=par("cex") * max(strwidth(paste0(leg.imin, " "))),
             min=usr[1], max=usr[2])
     # use of "ok" prevents display off the right or left of the plot
     # (necessary if user specifies xlim)
